@@ -1,11 +1,15 @@
 package Pod::Weaver::Section::SQL;
 {
-  $Pod::Weaver::Section::SQL::VERSION = '0.0203';
+  $Pod::Weaver::Section::SQL::VERSION = '0.03';
 }
 
 # ABSTRACT: Document SQL more easily by referencing only the SQL command in POD
 
 
+use strict;
+use warnings;
+
+use Carp;
 use List::Util 1.33 qw/any/;
 
 use Moose;
@@ -86,7 +90,7 @@ sub transform_document {
             }
             push @{ $container->children },
               Pod::Elemental::Element::Generic::Text->new(
-                content => $self->_format_sql( $node->content . "\n\n" ) );
+                content => $self->format_sql( $node->content ) . "\n\n" );
         }
         else {
             push @{ $container->children }, $node;
@@ -143,16 +147,39 @@ has keywords => (
     },
 );
 
-sub _format_sql {
-    my ($self, $content) = @_;
+
+sub format_sql {
+    my ( $self, $content ) = @_;
+
+    if ( $content =~ m/SQL::Abstract/ ) {
+        $content =~ s/\n//g;
+        require SQL::Abstract;
+        $content =~ s/SQL::Abstract/\$sql_abstract/;
+        my $sql_abstract = SQL::Abstract->new;
+        my ($stmt, @bind) = eval $content;
+        if ($@) {
+          croak "Trying to eval $content\n" . $@;
+        }
+        $content = $stmt;
+    }
 
     my %words;
     map { $words{$_} = 1 } split ' ', $content;
 
     $content =~ s/C<([^>]+)>/C\[__\?:__$1__:\?__\]/g;
 
+    my @keywords;
+    if (    ref( $self->keywords )
+        and ref( $self->keywords ) eq 'ARRAY' )
+    {
+        @keywords = @{ $self->keywords };
+    }
+    else {
+        @keywords = split( ',', $self->keywords );
+    }
+
     for my $word ( keys %words ) {
-        if ( any { $word eq $_ } @{ $self->keywords } ) {
+        if ( any { $word eq $_ } @keywords ) {
             my $new_word = $word;
             $new_word =~ s/</E\[__?:__lt__:?__\]/;
             $new_word =~ s/>/E\[__?:__gt__:?__\]/;
@@ -179,18 +206,20 @@ Pod::Weaver::Section::SQL - Document SQL more easily by referencing only the SQL
 
 =head1 VERSION
 
-version 0.0203
+version 0.03
 
 =head1 SYNOPSIS
 
 Update your weaver.ini file with
 
   [SQL]
-  command = sql
+  keywords = SELECT, INSERT, DELETE
 
 It will then gather all B<=sql> section into one unique SQL section in your
 documentation.
 
+You can let keywords to it's default that is all known L<SQL::Statement> keywords.
+
 =head1 METHODS
 
 =head2 transform_document
@@ -207,6 +236,12 @@ Commands into the same Pod document node.
 
 Remove the section gathered in L<transform_document> from the source document.
 
+=head2 format_sql
+
+  my $formated = $section_sql->format_sql('SELECT toto FROM tata');
+
+Reads and format SQL statements into Pod emphasised content.
+
 =head1 AUTHOR
 
 Armand Leclercq <armand.leclercq@gmail.com>
